@@ -1,6 +1,7 @@
 /* -*- c-basic-offset: 2 -*- */
 /*
-  Copyright(C) 2015-2017 Brazil
+  Copyright(C) 2015-2018 Brazil
+  Copyright(C) 2018 Kouhei Sutou <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -19,6 +20,8 @@
 
 #pragma once
 
+#include <groonga/option.h>
+
 #ifdef  __cplusplus
 extern "C" {
 #endif
@@ -33,11 +36,16 @@ GRN_API grn_bool grn_obj_is_true(grn_ctx *ctx, grn_obj *obj);
 GRN_API grn_bool grn_obj_is_builtin(grn_ctx *ctx, grn_obj *obj);
 GRN_API grn_bool grn_obj_is_bulk(grn_ctx *ctx, grn_obj *obj);
 GRN_API grn_bool grn_obj_is_text_family_bulk(grn_ctx *ctx, grn_obj *obj);
+GRN_API grn_bool grn_obj_is_number_family_bulk(grn_ctx *ctx, grn_obj *obj);
+GRN_API grn_bool grn_obj_is_vector(grn_ctx *ctx, grn_obj *obj);
 GRN_API grn_bool grn_obj_is_table(grn_ctx *ctx, grn_obj *obj);
+GRN_API grn_bool grn_obj_is_lexicon(grn_ctx *ctx, grn_obj *obj);
 GRN_API grn_bool grn_obj_is_column(grn_ctx *ctx, grn_obj *obj);
+GRN_API grn_bool grn_obj_is_scalar_column(grn_ctx *ctx, grn_obj *obj);
 GRN_API grn_bool grn_obj_is_vector_column(grn_ctx *ctx, grn_obj *obj);
 GRN_API grn_bool grn_obj_is_weight_vector_column(grn_ctx *ctx, grn_obj *obj);
 GRN_API grn_bool grn_obj_is_reference_column(grn_ctx *ctx, grn_obj *obj);
+GRN_API grn_bool grn_obj_is_data_column(grn_ctx *ctx, grn_obj *obj);
 GRN_API grn_bool grn_obj_is_index_column(grn_ctx *ctx, grn_obj *obj);
 GRN_API grn_bool grn_obj_is_accessor(grn_ctx *ctx, grn_obj *obj);
 GRN_API grn_bool grn_obj_is_key_accessor(grn_ctx *ctx, grn_obj *obj);
@@ -52,6 +60,7 @@ GRN_API grn_bool grn_obj_is_normalizer_proc(grn_ctx *ctx, grn_obj *obj);
 GRN_API grn_bool grn_obj_is_token_filter_proc(grn_ctx *ctx, grn_obj *obj);
 GRN_API grn_bool grn_obj_is_scorer_proc(grn_ctx *ctx, grn_obj *obj);
 GRN_API grn_bool grn_obj_is_window_function_proc(grn_ctx *ctx, grn_obj *obj);
+GRN_API grn_bool grn_obj_is_expr(grn_ctx *ctx, grn_obj *obj);
 
 GRN_API grn_rc grn_obj_cast(grn_ctx *ctx,
                             grn_obj *src,
@@ -70,6 +79,23 @@ GRN_API grn_bool grn_obj_name_is_column(grn_ctx *ctx,
                                         const char *name,
                                         int name_len);
 
+GRN_API grn_bool grn_obj_is_corrupt(grn_ctx *ctx, grn_obj *obj);
+GRN_API size_t grn_obj_get_disk_usage(grn_ctx *ctx, grn_obj *obj);
+
+GRN_API grn_rc grn_obj_set_option_values(grn_ctx *ctx,
+                                         grn_obj *obj,
+                                         const char *name,
+                                         int name_length,
+                                         grn_obj *values);
+GRN_API grn_option_revision
+grn_obj_get_option_values(grn_ctx *ctx,
+                          grn_obj *obj,
+                          const char *name,
+                          int name_length,
+                          grn_option_revision revision,
+                          grn_obj *values);
+GRN_API grn_rc grn_obj_clear_option_values(grn_ctx *ctx, grn_obj *obj);
+
 #ifdef __cplusplus
 }
 #endif
