@@ -28,13 +28,12 @@ module Groonga
       Operator::BITWISE_OR,
       Operator::BITWISE_XOR,
       Operator::BITWISE_AND,
-      Operator::BITWISE_NOT,
       Operator::SHIFTL,
       Operator::SHIFTR,
       Operator::SHIFTRR,
       Operator::PLUS,
-      Operator::MINUS,
       Operator::STAR,
+      Operator::SLASH,
       Operator::MOD,
     ]
 
@@ -47,6 +46,25 @@ module Groonga
 
     UNARY_OPERATIONS = [
       Operator::NOT,
+      Operator::BITWISE_NOT,
+      Operator::INCR,
+      Operator::DECR,
+      Operator::INCR_POST,
+      Operator::DECR_POST,
+    ]
+
+    ASSIGN_ARITHMETIC_OPERATIONS = [
+      Operator::STAR_ASSIGN,
+      Operator::SLASH_ASSIGN,
+      Operator::MOD_ASSIGN,
+      Operator::PLUS_ASSIGN,
+      Operator::MINUS_ASSIGN,
+      Operator::SHIFTL_ASSIGN,
+      Operator::SHIFTR_ASSIGN,
+      Operator::SHIFTRR_ASSIGN,
+      Operator::AND_ASSIGN,
+      Operator::XOR_ASSIGN,
+      Operator::OR_ASSIGN,
     ]
 
     def initialize(expression)
@@ -67,17 +85,53 @@ module Groonga
           node = ExpressionTree::LogicalOperation.new(code.op, nodes)
           stack.push(node)
         when *RELATION_OPERATORS, *ARITHMETIC_OPERATORS
+          options = {}
+          options[:parameter] = stack.pop if code.n_args == 3
+          options[:value] = code.value.value if code.value
           right = stack.pop
           left = stack.pop
-          node = ExpressionTree::BinaryOperation.new(code.op, left, right)
+          node = ExpressionTree::BinaryOperation.new(code.op,
+                                                     left,
+                                                     right,
+                                                     options)
           stack.push(node)
         when *UNARY_OPERATIONS
           value = stack.pop
           node = ExpressionTree::UnaryOperation.new(code.op, value)
           stack.push(node)
+        when *ASSIGN_ARITHMETIC_OPERATIONS
+          value = stack.pop
+          variable = stack.pop
+          node = ExpressionTree::AssignBinaryOperation.new(code.op,
+                                                           variable,
+                                                           value)
+          stack.push(node)
+        when Operator::MINUS
+          if code.n_args == 1
+            value = stack.pop
+            node = ExpressionTree::UnaryOperation.new(code.op, value)
+          else
+            right = stack.pop
+            left = stack.pop
+            node = ExpressionTree::BinaryOperation.new(code.op, left, right)
+          end
+          stack.push(node)
+        when Operator::GET_REF
+          node = ExpressionTree::Reference.new(code.value)
+          stack.push(node)
         when Operator::GET_VALUE
           node = ExpressionTree::Variable.new(code.value)
           stack.push(node)
+        when Operator::GET_MEMBER
+          index = stack.pop
+          variable = stack.pop
+          node = ExpressionTree::Member.new(variable, index)
+          stack.push(node)
+        when Operator::ASSIGN
+          value = stack.pop
+          variable = stack.pop
+          node = ExpressionTree::Assign.new(variable, value)
+          stack.push(node)
         when Operator::PUSH
           case code.value
           when Procedure
@@ -86,8 +140,10 @@ module Groonga
             node = ExpressionTree::IndexColumn.new(code.value)
           when Accessor
             node = ExpressionTree::Accessor.new(code.value)
-          when HashTable
-            node = ExpressionTree::Options.new(code.value)
+          when Table
+            node = ExpressionTree::Table.new(code.value)
+          when Void
+            node = ExpressionTree::Null.new
           else
             node = ExpressionTree::Constant.new(code.value.value)
           end
@@ -104,13 +160,19 @@ module Groonga
           raise "unknown operator: #{code.inspect}"
         end
       end
-      stack.pop
+      if stack.size == 1
+        stack.pop
+      else
+        # Unsupported expression
+        nil
+      end
     end
 
     private
     def add_logical_operation_node(operator, nodes, node)
       if node.is_a?(ExpressionTree::LogicalOperation) and
-          node.operator == operator
+          node.operator == operator and
+          node.operator != Operator::AND_NOT
         nodes.concat(node.nodes)
       else
         nodes << node
